@@ -9,6 +9,9 @@ our $VERSION = "0.01";
 
 use lib 't/lib';
 use Data::Dumper qw(Dumper);
+
+# require 'CommentOuted.pl'; # will be ignored
+my $dummys = 1;        # require 'CommentOuted.pl'; # will be ignored
 require "Dummy.pl";    # does not exist
 
 exit;
