@@ -9,6 +9,9 @@ our $VERSION = "0.01";
 
 use Data::Dumper qw(Dumper);
 require Encode;
+
+# use CommentOuted qw(Dummy); # will be ignored
+my $dummys = 1;         # use CommentOuted qw(Dummy); # will be ignored
 use Dummy qw(Dummy);    # does not exist
 
 exit;
